Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(624)

Unified Diff: chrome/browser/ui/cocoa/browser/password_generation_bubble_controller.mm

Issue 15553008: Instant Extended: Reduce clipping in omnibox (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/ui/cocoa/find_bar/find_bar_text_field_cell.mm » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/cocoa/browser/password_generation_bubble_controller.mm
diff --git a/chrome/browser/ui/cocoa/browser/password_generation_bubble_controller.mm b/chrome/browser/ui/cocoa/browser/password_generation_bubble_controller.mm
index d3c8ca9714a2254ae2168bdbf4874c4089bd9109..878d22ff16ee4a8e6882cfd6cf4db7cfb68ddd24 100644
--- a/chrome/browser/ui/cocoa/browser/password_generation_bubble_controller.mm
+++ b/chrome/browser/ui/cocoa/browser/password_generation_bubble_controller.mm
@@ -221,7 +221,7 @@ const CGFloat kIconSize = 26.0;
}
- (NSRect)textFrameForFrame:(NSRect)cellFrame {
- // Baseclass insets the rect by baselineAdjust.
+ // Baseclass insets the rect by top and bottom offsets.
NSRect textFrame = [super textFrameForFrame:cellFrame];
textFrame = [self getTextFrame:textFrame];
return [self adjustFrameForFrame:textFrame];
@@ -269,7 +269,11 @@ const CGFloat kIconSize = 26.0;
[view addTrackingArea:area];
}
-- (CGFloat)baselineAdjust {
+- (CGFloat)topTextFrameOffset {
+ return 1.0;
+}
+
+- (CGFloat)bottomTextFrameOffset {
return 1.0;
}
« no previous file with comments | « no previous file | chrome/browser/ui/cocoa/find_bar/find_bar_text_field_cell.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698